---
name: "🚀 Submit a Feature request"
about: Use this template if you want a feature added which is currently not present
labels: enhancement
---

<!-- Describe your desired feature and why it is important. If possible state what you can and are willing to do to help with it -->
